@@ -74,6 +74,13 @@
  */
 class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
 {
+    /**
+     * The default ports to use for a connection.
+     *
+     * @var array
+     */
+    protected $_defaultPorts = array(110, 995);
+
     /**
      * The list of deleted messages.
      *
@@ -88,17 +95,6 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
      */
     protected $_fetchDataClass = 'Horde_Imap_Client_Data_Fetch_Pop3';
 
-    /**
-     */
-    public function __construct(array $params = array())
-    {
-        parent::__construct($params);
-
-        if (empty($params['port'])) {
-            $this->setParam('port', in_array($this->getParam('secure'), array('ssl', 'sslv2', 'sslv3')) ? 995 : 110);
-        }
-    }
-
     /**
      */
     protected function _initCache($current = false)
@@ -186,25 +182,34 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
     {
         $this->_connect();
 
+        $secure = $this->getParam('secure');
+
         // Switch to secure channel if using TLS.
         if (!$this->isSecureConnection() &&
-            ($this->getParam('secure') == 'tls')) {
+            (($secure === 'tls') || $secure === true)) {
             // Switch over to a TLS connection.
             if (!$this->queryCapability('STLS')) {
-                throw new Horde_Imap_Client_Exception(
-                    Horde_Imap_Client_Translation::t("Could not open secure connection to the POP3 server.") . ' ' . Horde_Imap_Client_Translation::t("Server does not support secure connections."),
-                    Horde_Imap_Client_Exception::LOGIN_TLSFAILURE
-                );
-            }
+                if ($secure === 'tls') {
+                    throw new Horde_Imap_Client_Exception(
+                        Horde_Imap_Client_Translation::t("Could not open secure connection to the POP3 server.") . ' ' . Horde_Imap_Client_Translation::t("Server does not support secure connections."),
+                        Horde_Imap_Client_Exception::LOGIN_TLSFAILURE
+                    );
+                } else {
+                    $this->setParam('secure', false);
+                }
+            } else {
+                $this->_sendLine('STLS');
 
-            $this->_sendLine('STLS');
+                $this->setParam('secure', 'tls');
 
-            if (!$this->_connection->startTls()) {
-                $this->logout();
-                throw new Horde_Imap_Client_Exception(
-                    Horde_Imap_Client_Translation::t("Could not open secure connection to the POP3 server."),
-                    Horde_Imap_Client_Exception::LOGIN_TLSFAILURE
-                );
+                if (!$this->_connection->startTls()) {
+                    $this->logout();
+                    throw new Horde_Imap_Client_Exception(
+                        Horde_Imap_Client_Translation::t("Could not open secure connection to the POP3 server."),
+                        Horde_Imap_Client_Exception::LOGIN_TLSFAILURE
+                    );
+                }
+                $this->_debug->info('Successfully completed TLS negotiation.');
             }
 
             // Expire cached CAPABILITY information
@@ -230,7 +235,8 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
                 $this->_tryLogin($method);
                 $this->_setInit('authmethod', $method);
 
-                if (!empty($this->_temp['no_capa'])) {
+                if (!empty($this->_temp['no_capa']) ||
+                    !$this->queryCapability('UIDL')) {
                     $this->_capability();
                 }
 
@@ -260,7 +266,27 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             return;
         }
 
-        $this->_connection = new Horde_Imap_Client_Socket_Connection_Pop3($this, $this->_debug);
+        try {
+            $this->_connection = new Horde_Imap_Client_Socket_Connection_Pop3(
+                $this->getParam('hostspec'),
+                $this->getParam('port'),
+                $this->getParam('timeout'),
+                $this->getParam('secure'),
+                array(
+                    'debug' => $this->_debug
+                )
+            );
+            if (!$this->_connection->secure) {
+                $this->setParam('secure', false);
+            }
+        } catch (Horde\Socket\Client\Exception $e) {
+            $e2 = new Horde_Imap_Client_Exception(
+                Horde_Imap_Client_Translation::t("Error connecting to mail server."),
+                Horde_Imap_Client_Exception::SERVER_CONNECT
+            );
+            $e2->details = $e->details;
+            throw $e2;
+        }
 
         $line = $this->_getResponse();
 
@@ -412,7 +438,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
      */
     protected function _openMailbox(Horde_Imap_Client_Mailbox $mailbox, $mode)
     {
-        if (strcasecmp($mailbox, 'INBOX') !== 0) {
+        if ($mailbox != 'INBOX') {
             throw new Horde_Imap_Client_Exception_NoSupportPop3('Mailboxes other than INBOX');
         }
         $this->_changeSelected($mailbox, $mode);
@@ -477,8 +503,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
      */
     protected function _status($mboxes, $flags)
     {
-        if ((count($mboxes) > 1) ||
-            (strcasecmp(reset($mboxes), 'INBOX') !== 0)) {
+        if ((count($mboxes) > 1) || (reset($mboxes) != 'INBOX')) {
             throw new Horde_Imap_Client_Exception_NoSupportPop3('Mailboxes other than INBOX');
         }
 
@@ -1146,7 +1171,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
         $ob = array('resp' => '');
 
         $read = explode(' ', rtrim($this->_connection->read(), "\r\n"), 2);
-        if (!in_array($read[0], array('+OK', '-ERR'))) {
+        if (!in_array($read[0], array('+OK', '-ERR', '+'))) {
             $this->_debug->info("ERROR: IMAP read/timeout error.");
             throw new Horde_Imap_Client_Exception(
                 Horde_Imap_Client_Translation::t("Error when communicating with the mail server."),
@@ -1163,6 +1188,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
 
         switch ($read[0]) {
         case '+OK':
+        case '+':
             if ($respcode) {
                 $ob['resp'] = $respcode->text;
             } elseif (isset($read[1])) {
@@ -1235,9 +1261,9 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             $orig_read = $this->_connection->read();
             $read = rtrim($orig_read, "\r\n");
 
-            if ($read == '.') {
+            if ($read === '.') {
                 break;
-            } elseif (substr($read, 0, 2) == '..') {
+            } elseif (substr($read, 0, 2) === '..') {
                 $read = substr($read, 1);
             }
 
@@ -1285,7 +1311,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
         $ret = new stdClass;
 
         $text = trim($text);
-        if ($text[0] == '[') {
+        if ($text[0] === '[') {
             $pos = strpos($text, ' ', 2);
             $end_pos = strpos($text, ']', 2);
             if ($pos > $end_pos) {
